@@ -419,6 +419,15 @@ class MockTest(unittest2.TestCase):
         mock.__name__ = 'foo'
         self.assertEqual(mock.__name__, 'foo')
 
+    def test_spec_list_subclass(self):
+        class Sub(list):
+            pass
+        mock = Mock(spec=Sub(['foo']))
+
+        mock.append(3)
+        mock.append.assert_called_with(3)
+        self.assertRaises(AttributeError, getattr, mock, 'foo')
+
 
     def testSpecClass(self):
         class X(object):
